package com.ynet.life.search;

import java.sql.ResultSet;
import java.sql.SQLException;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;

/* loaded from: com_ynet_life_search.jar:com/ynet/life/search/RCUBankNoIndexBuilder.class */
public class RCUBankNoIndexBuilder extends AbstractDBIndexBuilder {
    private static final String SQL_BANK_NO = "SELECT RBN_BANKNO, RBN_BANKNAME, RBN_STT, RCIT_CODE, RCIT_NAME, PIF_CODE, PIF_NAME  FROM PUB_RCUBANKNO, PUB_RCUCITYINFO, PUB_PROVINCEINFO  WHERE RBN_CITYCODE = RCIT_CODE     AND RBN_PROVINCECODE = RCIT_PROVINCE     AND RCIT_PROVINCE = PIF_CODE ";
    private static final String SQL_BANK_INDEX_FIELD = "SELECT RBN_BANKNO, RBN_BANKNAME, RBN_STT, RCIT_CODE, RCIT_NAME, PIF_CODE, PIF_NAME";

    public RCUBankNoIndexBuilder(String indexFolderFile) {
        super(indexFolderFile, SQL_BANK_NO, SQL_BANK_INDEX_FIELD);
    }

    @Override // com.ynet.life.search.AbstractDBIndexBuilder
    protected Document getDocument(ResultSet rs) throws SQLException {
        String bankNo = rs.getString("RBN_BANKNO");
        String bankName = rs.getString("RBN_BANKNAME");
        String state = rs.getString("RBN_STT");
        String cityCode = rs.getString("RCIT_CODE");
        String cityName = rs.getString("RCIT_NAME");
        String provCode = rs.getString("PIF_CODE");
        String provName = rs.getString("PIF_NAME");
        String bankType = rs.getString("PIF_CODE");
        String bankNo2 = bankNo == null ? "" : bankNo.trim();
        String fullContents = String.valueOf(provName) + cityName + bankName;
        Document doc = new Document();
        doc.add(new Field("keyWord", bankNo2, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("fullContents", fullContents, Field.Store.YES, Field.Index.ANALYZED));
        doc.add(new Field("bankType", bankType, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("unionBankNo", bankNo2, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("bankName", bankName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("state", state, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("cityCode", cityCode, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("cityName", cityName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("provinceCode", provCode, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("provinceName", provName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        return doc;
    }
}
